<script src="/static/jsim.js"> </script>


<div class="modal" id="smallModal" role="dialog">
<div class="modal-dialog modal-sm">
<div id="smallModalContent" class="modal-content">
</div>
</div>
</div>

<div class="modal" id="bigModal" role="dialog">
<div class="modal-dialog modal-lg">
<div id="bigModalContent" class="modal-content">
</div>
</div>
</div>

<div class="modal" id="mediumModal" role="dialog">
<div class="modal-dialog">
<div id="mediumModalContent" class="modal-content">
</div>
</div>
</div>

<div class="modal" id="modalError" role="dialog">
<div class="modal-dialog modal-sm">
<div id="modalContentError" class="modal-content" style="background-color:#E1DEDE">
<div class="modal-header">
<button type="button"  class="close" data-dismiss="modal">&times;</button>
<h5>  <span class="glyphicon glyphicon-warning-sign"></span> Warning </h5>
</div>

<div class="modal-body">

<div id="messageError">

</div>
</div>

</div>
</div>
</div>

<! it seems the order matters when calling modal show ?>
<div class="modal " id="modalWait" role="dialog"   
data-backdrop="static" data-keyboard="false">
<div class="modal-dialog modal-sm">
<div id="modalContentWait" class="modal-content">

<div class="modal-body" style="background-color:#E1DEDE">
<h5> 
<span class="glyphicon glyphicon-time"></span>
Please, wait
<small> It may take a while ... </small>

<h5>

</div>

</div>
</div>
</div>





